@@ -31,37 +31,14 @@ OModel=oclingo.Model
 OSolveHandle=oclingo.SolveHandle
 OControl=oclingo.Control
 
-from clingo import *
-__all__ = list([ k for k in oclingo.__dict__.keys() if k[0] != '_'])
-__version__ = oclingo.__version__
-
-
 if oclingo.__version__ >= "5.5.0":
-
     from clingo.ast import parse_string
-
-    def control_add_facts(ctrl, facts):
-        with ctrl.backend() as bknd:
-            for f in facts:
-                raw=f.raw if isinstance(f,Predicate) else f
-                atm = bknd.add_atom(raw)
-                bknd.add_rule([atm])
 else:
     from clingo import parse_program
 
-    def control_add_facts(ctrl, facts):
-        with ctrl.builder() as bldr:
-            line=1
-            for f in facts:
-                raw=f.raw if isinstance(f,Predicate) else f
-                floc = { "filename" : "<input>", "line" : line , "column" : 1 }
-                location = { "begin" : floc, "end" : floc }
-                r = ast.Rule(location,
-                             ast.Literal(location, ast.Sign.NoSign,
-                                         ast.SymbolicAtom(ast.Symbol(location,raw))),
-                             [])
-                bldr.add(r)
-                line += 1
+from clingo import *
+__all__ = list([ k for k in oclingo.__dict__.keys() if k[0] != '_'])
+__version__ = oclingo.__version__
 
 # ------------------------------------------------------------------------------
 # Helper function to smartly build a unifier if only a list of predicates have
