@@ -2,13 +2,19 @@
 # Combine all the main aspects of the Clorm ORM into one unified export.
 # -----------------------------------------------------------------------------
 
+from .noclingo import *
 from .core import *
 from .factbase import *
 from .query import *
-from .unifier import *
+from .symbols_facts import *
 from .atsyntax import *
 
 __all__ = [
+    'ClormError',
+    'UnifierNoMatchError',
+    'NonFactError',
+    'BaseField',
+    'Raw',
     'RawField',
     'IntegerField',
     'StringField',
@@ -27,7 +33,9 @@ __all__ = [
     'Placeholder',
     'refine_field',
     'combine_fields',
+    'define_flat_list_field',
     'define_nested_list_field',
+    'define_enum_field',
     'simple_predicate',
     'unify',
     'path',
@@ -51,6 +59,16 @@ __all__ = [
     'basic_join_order',
     'oppref_join_order',
     'make_function_asp_callable',
-    'make_method_asp_callable'
+    'make_method_asp_callable',
+    'SymbolMode',
+    'clingo_to_noclingo',
+    'noclingo_to_clingo',
+    'set_symbol_mode',
+    'get_symbol_mode',
+    'symbols',
+    'control_add_facts',
+    'symbolic_atoms_to_facts',
+    'parse_fact_string',
+    'parse_fact_files'
     ]
 
